@@ -33,6 +33,8 @@ class TestParameters(TestCase):
 
     vals = {
         "base_repository": "repository",
+        "base_ref": "base_ref",
+        "base_rev": "base_rev",
         "build_date": 0,
         "build_number": 1,
         "do_not_optimize": [],
